@@ -1528,7 +1528,12 @@ describe('mapnik.Image ', function() {
     it('be able to create image with zero allocation / from raw buffer', function() {
         var im = new mapnik.Image.open('test/data/images/sat_image.png');
         assert.equal(im.premultiplied(), false);
-        var im2 = new mapnik.Image.fromBufferSync(im.width(), im.height(), im.data());
+        // note: makes copy when data() is called
+        var data = im.data();
+        var im2 = new mapnik.Image.fromBufferSync(im.width(), im.height(), data);
+        // We attach `data` onto the image so that v8 will not
+        // clean it up before im2 is destroyed
+        assert.equal(im2._buffer,data);
         assert.equal(im2.premultiplied(), false);
         assert.equal(0, im.compare(im2, {threshold:0}));
         im.premultiplySync();
@@ -1544,6 +1549,14 @@ describe('mapnik.Image ', function() {
         });
         assert.equal(im3.premultiplied(), true);
         assert.equal(im3.painted(), true);
+
+        // Just for testing (not good practice) we modify data
+        // and ensure that im2._buffer also reflects the modification
+        // as another way to prove they are the same instance
+        assert.equal(im2._buffer[0],23);
+        data[0] = 99;
+        assert.equal(im2._buffer[0],99);
+
     });
 
     it('should fail to use fromBufferSync due to bad input', function() {
